@@ -92,6 +92,8 @@ class SetupPanel(object):
         "duplicate_role_embed",
         "duplicate_emojis",
         "duplicate_emoji_embed",
+        "timeout_embed",
+        "cancel_embed",
         "_coros",
         "_emojis",
         "_ret",
@@ -107,6 +109,8 @@ class SetupPanel(object):
                  duplicate_role_embed: discord.Embed = None,
                  duplicate_emojis: bool = False,
                  duplicate_emoji_embed: discord.Embed = None,
+                 timeout_embed: discord.Embed = None,
+                 cancel_embed: discord.Embed = None,
                  error_color: Union[discord.Color, int] = discord.Color.dark_red()) -> None:
         self.bot = bot
         self.ctx = ctx
@@ -127,6 +131,8 @@ class SetupPanel(object):
         ).set_footer(
             text="React to the original message"
         )
+        self.timeout_embed = timeout_embed
+        self.cancel_embed = cancel_embed
         self._coros: List[_CoroStep] = []
         self._emojis: List[str] = []
         self._ret = []
@@ -668,7 +674,7 @@ class SetupPanel(object):
                 self._ret.append(res)
             except _Cancel:
                 await self.ctx.channel.send(
-                    embed=discord.Embed(
+                    embed=self.cancel_embed or discord.Embed(
                         title=f"{self.title.title()} Canceled",
                         description=f"{self.ctx.author.mention}, the {self.title.lower()} was canceled",
                         color=self.error_color,
@@ -677,7 +683,7 @@ class SetupPanel(object):
                 return None
             except _Timeout as t:
                 await self.ctx.channel.send(
-                    embed=discord.Embed(
+                    embed=self.timeout_embed or discord.Embed(
                         title=f"{self.title.title()} Timed Out",
                         description=f"{self.ctx.author.mention}, the {self.title.lower()} timed out after {t.timeout} seconds of inactivity",
                         color=self.error_color,
